@@ -1,13 +1,3 @@
-use std::sync::Arc;
-
-use mnesia::{storage::Storage, RQuery, Event, migration};
-use serde_derive::{Serialize, Deserialize};
-use tokio::sync::mpsc::{channel, self};
-
-
-mod mnesia;
-
-
 #[tokio::main]
 async fn main() {
 
@@ -72,4 +62,4 @@ impl User2 {
     pub fn new(fullname: String, age: i32) -> Self {
         User2 { fullname, age }
     } 
-}
\ No newline at end of file
+}
